@@ -1,5 +1,6 @@
 /**
  * Copyright (C) 2012 Martin Sandsmark <martin.sandsmark@kde.org>
+ * Copyright (C) 2014 Arnold Dumas <contact@arnolddumas.fr>
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -14,20 +15,27 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SCROBBLESETTINGS_H
-#define SCROBBLESETTINGS_H
+#ifndef JUK_SCROBBLESETTINGS_H
+#define JUK_SCROBBLESETTINGS_H
 
-#include <KDialog>
+#include <QDialog>
+#include <KWallet>
+
+#include <memory>
+
+using namespace KWallet;
 
 class KLineEdit;
-class KPushButton;
+class QAbstractButton;
+class QPushButton;
 class QLabel;
 
-class ScrobbleConfigDlg : public KDialog
+class ScrobbleConfigDlg : public QDialog
 {
     Q_OBJECT
+
 public:
-    explicit ScrobbleConfigDlg(QWidget* parent = 0, Qt::WindowFlags f = 0);
+    explicit ScrobbleConfigDlg(QWidget* parent = nullptr);
 
 private slots:
     void testLogin();
@@ -39,8 +47,11 @@ private slots:
 private:
     KLineEdit *m_usernameEdit;
     KLineEdit *m_passwordEdit;
-    KPushButton *m_testButton;
+    QPushButton *m_testButton;
+    QAbstractButton *m_saveButton;
     QLabel *m_testFeedbackLabel;
+
+    std::unique_ptr<Wallet> m_wallet;
 };
 
-#endif//SCROBBLESETTINGS_H
+#endif //JUK_SCROBBLESETTINGS_H
